#!/usr/bin/env bash
#* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
#*                                                                           *
#*    This file is part of the test engine for the 11th DIMACS challenge     *
#*                                                                           *
#* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

CHECK=1
FILES=""
for i in $@
do
    if test "-n" = "$i"
    then
	CHECK=0
    else
	FILES="$FILES $i"
    fi
done

for j in $FILES
do
    EVALFILE=$j

    echo "evaluating $EVALFILE"

    # construct paths
    SCRIPTPATH=`pwd`
    TSTPATH=$SCRIPTPATH/testsets
    BENCHPATH=$SCRIPTPATH/bench
    SOLUTIONPATH=$SCRIPTPATH/results/solutions
    SOLCHECK=checker/solchecker

    NAME=`basename $EVALFILE .eval`
    DIR=`dirname $EVALFILE`
    OUTFILE=$DIR/$NAME.out
    ERRFILE=$DIR/$NAME.err
    RESFILE=$DIR/$NAME.res
    TMPFILE=$DIR/$NAME.tmp

    echo $NAME
    #TSTNAME=`echo $NAME | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-.]*\).\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\).\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)/\1/g'`
    TSTNAME=`echo $NAME | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\..*/\1/g'`
    echo $TSTNAME

    echo > $TMPFILE

    SOLUFILE=$TSTPATH/$TSTNAME.solu
    TESTFILE=$TSTPATH/$TSTNAME.test

    echo $TESTFILE

    # check if a solution  file/link exists
    if test ! -e $SOLUFILE
    then
	echo "Warning: solution file/link <$TSTNAME.solu> does not exist in <testsets> folder; therefore, no consistency check and primal integral computation"
	SOLUFILE=""
    fi

    # loop over all instance names which are listed in the test set file name
    for i in `cat $EVALFILE`
    do
	INSTANCE=`basename $i .txt`
	INSTANCE=`basename $INSTANCE .sol`
	#INSTANCENAME=`echo $INSTANCE | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-.]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)/\2/g'`
	INSTANCE=`echo $INSTANCE | sed 's/\([a-zA-Z0-9_-]*\).\([a-zA-Z0-9_-]*\).*/\2/g'`

	echo @01 $INSTANCE =========== >> $TMPFILE

	# check if the current solution file exists
	if test -f $i
	then
	    SOLFILE=$i

	    PROBINST=`cat ${TESTFILE} | grep ${INSTANCE}.stp`

	    cat $SOLFILE >> $TMPFILE

	    if test "$CHECK" = "1"
	    then
		if test -e $SOLCHECK
		then
		    echo "checking solution '$INSTANCE' for '$PROBINST'..."
		    ./$SOLCHECK $PROBINST $SOLFILE >> $TMPFILE
		else
		    echo "solution checker not available"
		fi
	    else
		echo "solution checking disabled"
	    fi
	else
	    echo "file $i missing"
	fi
	echo =ready= >> $TMPFILE
    done

    awk -f scripts/parse.awk $BENCHPATH/score.log $SOLUFILE $TMPFILE | tee $RESFILE
done
