#* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
#*                                                                           *
#*    This file is part of the test engine for the 11th DIMACS challenge     *
#*                                                                           *
#* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

SHELL=$1
BINNAME=$2
TSTNAME=$3
TIMELIMIT=$4
THREADS=$5

# construct paths
SCRIPTPATH=`pwd`
BINPATH=$SCRIPTPATH/bin
RESULTSPATH=$SCRIPTPATH/results
SOLUTIONPATH=$SCRIPTPATH/results/solutions
TSTPATH=$SCRIPTPATH/testsets

# check if the solver link (binary) exists
if test ! -e $BINPATH/$BINNAME
then
    echo "ERROR: solver link <$BINNAME> does not exist in <bin> folder; see bin/README"
    exit;
fi

# check if the test set file/link exists
if test ! -e $TSTPATH/$TSTNAME.test
then
    echo "ERROR: test set file/link <$TSTPATH/$TSTNAME.test> does not exist"
    exit;
fi

SOLUFILE=$TSTPATH/$TSTNAME.solu

# check if the results folder exists, if not create it
if test ! -e $RESULTSPATH
then
    mkdir $RESULTSPATH
fi

# check if the solution folder exists, if not create it
if test ! -e $SOLUTIONPATH
then
    mkdir $SOLUTIONPATH
fi

# construct name of output and results file
BASENAME=$RESULTSPATH/$TSTNAME.$BINNAME.$THREADS.$TIMELIMIT
EVALFILE=$BASENAME.eval
OUTFILE=$BASENAME.out

# post system information and current time into the output file
uname -a > $OUTFILE
date >> $OUTFILE
> $EVALFILE

# loop over all instance names which are listed in the test set file name
for i in `cat $TSTPATH/$TSTNAME.test`
do
    # check if the current instance exists
    if test -f $i
    then

	FILENAME=`basename $i .gz`
	FILENAME=`basename $FILENAME .stp`

	SOLFILE=$SOLUTIONPATH/$TSTNAME.$FILENAME.$BINNAME.$THREADS.$TIMELIMIT.sol

	echo $SOLFILE >> $EVALFILE

        echo @01 $i ===========
        echo -----------------------------
        date
        echo -----------------------------
        TIMESTART=`date +"%s"`
	echo @03 $TIMESTART
	$SHELL -c " ulimit -f 2000000; ulimit -s unlimited; $BINPATH/$BINNAME $i $TIMELIMIT $THREADS $SOLFILE"
	echo
        TIMEEND=`date +"%s"`
	echo @04 $TIMEEND
	echo @05 $TIMELIMIT
	# check if a solution file was written
	if test -e $SOLFILE
	then
	    echo
	fi
        echo -----------------------------
        date
        echo -----------------------------
	echo
        echo =ready=
    else
        echo @02 FILE NOT FOUND: $i ===========
    fi
done 2>&1 | tee -a $OUTFILE

date >> $OUTFILE

$SCRIPTPATH/scripts/parse.sh $EVALFILE
#awk -f $SCRIPTPATH/scripts/parse.awk $SOLUFILE | tee $RESFILE
